@@ -4,4 +4,4 @@ extern void generate_gamma (double*, double*, double*, double*, double*, double*
 extern double generate_sig2 (double*, double*, double*, double*, int, int, int, double, double, double);
 extern double generate_phi2 (double*, int, double, double, double);
 extern void generate_SNP (double*, double*, double*, double*, double*, int, int, int, double, int, double**,
- 		int*, int*, int, double*, double*, int, int);
+ 		int*, int*, int, double*, double*, int);
